Slot: typeof - LinkML Model

# Slot: typeof

Names a parent type

URI: linkml:typeof

## Domain and Range

TypeDefinition → 0..1 TypeDefinition

## Parents

## Children

## Used by

- TypeDefinition

## Other properties

Comments: |  | the target type definition of the typeof slot is referred to as the "parent type"
|  | the type definition containing the typeof slot is referred to as the "child type"
|  | type definitions without a typeof slot are referred to as a "root type"